/// <reference types="node" />
import { Ask, Bid, BidShares, DecimalValue, ItemData, LandData, AvatarData, SpaceData } from "./types";
import { BytesLike } from "@ethersproject/bytes";
import { BigNumber, BigNumberish } from "@ethersproject/bignumber";
import { Wallet } from "ethers";
import { ContractTransaction } from "@ethersproject/contracts";
/********************
 * Type Constructors
 ********************
 */
export declare function constructItemData(tokenURI: string, metadataURI: string, contentHash: BytesLike, metadataHash: BytesLike): ItemData;
export declare function constructSpaceData(tokenURI: string, metadataURI: string, contentHash: BytesLike, metadataHash: BytesLike, isPublic: boolean, lands: Array<BigNumberish>): SpaceData;
export declare function constructAvatarData(tokenURI: string, metadataURI: string, contentHash: BytesLike, metadataHash: BytesLike): AvatarData;
export declare function constructLandData(tokenURI: string, metadataURI: string, contentHash: BytesLike, metadataHash: BytesLike, xCoordinate: number, yCoordinate: number): LandData;
export declare function constructBidShares(creator: number, owner: number, prevOwner: number): BidShares;
export declare function validateBidShares(creator: DecimalValue, owner: DecimalValue, prevOwner: DecimalValue): void;
export declare function constructAsk(currency: string, amount: BigNumberish): Ask;
export declare function constructBid(currency: string, amount: BigNumberish, bidder: string, recipient: string, sellOnShare: number): Bid;
export declare function validateBytes32(value: BytesLike): void;
export declare function validateURI(uri: string): void;
export declare function validateAndParseAddress(address: string): string;
export declare function chainIdToNetworkName(chainId: number): string;
/********************
 * Hashing Utilities
 ********************
 */
export declare function sha256FromBuffer(buffer: Buffer): string;
export declare function sha256FromHexString(data: string): string;
export declare function stripHexPrefix(hex: string): string;
/*********************
 * EIP-712 Utilities
 *********************
 */
export declare function approveERC20(wallet: Wallet, erc20Address: string, spender: string, amount: BigNumberish): Promise<ContractTransaction>;
export declare function isURIHashVerified(uri: string, expectedHash: BytesLike, timeout?: number): Promise<boolean>;
export declare function isItemDataVerified(itemData: ItemData, timeout?: number): Promise<boolean>;
export declare function isAvatarDataVerified(avatarData: AvatarData, timeout?: number): Promise<boolean>;
export declare function isSpaceDataVerified(spaceData: SpaceData, timeout?: number): Promise<boolean>;
export declare function isLandDataVerified(landData: LandData, timeout?: number): Promise<boolean>;
export declare function wrapETH(wallet: Wallet, wethAddress: string, amount: BigNumber): Promise<ContractTransaction>;
export declare function unwrapWETH(wallet: Wallet, wethAddress: string, amount: BigNumber): Promise<ContractTransaction>;
