"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const axios_1 = (0, tslib_1.__importDefault)(require("axios"));
const axios_mock_adapter_1 = (0, tslib_1.__importDefault)(require("axios-mock-adapter"));
const src_1 = require("../src");
jest.setTimeout(1000000);
describe('Users', () => {
    describe('getMotifProfiles', () => {
        const motifProfilesApiUri = 'https://motif.co/api/users';
        describe('success', () => {
            it('makes a POST request to /api/users and returns data', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                let mock = new axios_mock_adapter_1.default(axios_1.default);
                mock.onPost(motifProfilesApiUri).reply(200, [{ foo: 'bar' }]);
                const profiles = yield (0, src_1.getMotifProfiles)(['test']);
                expect(profiles).toEqual([{ foo: 'bar' }]);
            }));
        });
        describe('input validation', () => {
            it('raises if empty addresses', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                const spy = jest.spyOn(axios_1.default, 'post');
                try {
                    yield (0, src_1.getMotifProfiles)([]);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Empty addresses array'));
                }
                expect(spy).not.toHaveBeenCalled();
            }));
            it('raises if too many addresses', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                const spy = jest.spyOn(axios_1.default, 'post');
                const addresses = Array.from(new Array(101), () => '0sdf987sdf');
                try {
                    yield (0, src_1.getMotifProfiles)(addresses);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Addresses array exceeds max length of 100'));
                }
                expect(spy).not.toHaveBeenCalled();
            }));
        });
        describe('request error handling', () => {
            let mock;
            beforeEach(() => {
                mock = new axios_mock_adapter_1.default(axios_1.default);
            });
            it('throws with error message from response', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                mock.onPost(motifProfilesApiUri).reply(400, 'Custom error message from motif api');
                try {
                    yield (0, src_1.getMotifProfiles)(['asdf', '1234']);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Custom error message from motif api'));
                }
            }));
            it('raises if axios request fails', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                mock.onPost(motifProfilesApiUri).networkError();
                try {
                    yield (0, src_1.getMotifProfiles)(['asdf', '1234']);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Network Error'));
                }
            }));
            it('raises if axios response has no data', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                mock.onPost(motifProfilesApiUri).reply(200, null);
                try {
                    yield (0, src_1.getMotifProfiles)(['asdf', '1234']);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Error retrieving users'));
                }
            }));
            it('raises if axios response data is not a list', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                mock.onPost(motifProfilesApiUri).reply(200, {});
                try {
                    yield (0, src_1.getMotifProfiles)(['asdf', '1234']);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Error retrieving users'));
                }
            }));
            it('raises if axios response data is empty', () => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
                mock.onPost(motifProfilesApiUri).reply(200, []);
                try {
                    yield (0, src_1.getMotifProfiles)(['asdf', '1234']);
                    throw new Error('should throw');
                }
                catch (err) {
                    expect(err).toEqual(Error('Error retrieving users'));
                }
            }));
        });
    });
});
//# sourceMappingURL=users.test.js.map